summaryrefslogtreecommitdiff
path: root/lib/libutil/secure_path.c
diff options
context:
space:
mode:
authorwiz <wiz@NetBSD.org>2003-01-06 20:30:28 +0000
committerwiz <wiz@NetBSD.org>2003-01-06 20:30:28 +0000
commit1035faff1d69d2b2b87d1edb2ef3c0b0be73af7a (patch)
tree4bb2a96f03fc8e94de278ea70f7bc8d246d7e9b5 /lib/libutil/secure_path.c
parenteca381fce47f9f7c9e56dd33f06c3deea8ea319a (diff)
writable, not writeable.
Diffstat (limited to 'lib/libutil/secure_path.c')
-rw-r--r--lib/libutil/secure_path.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/libutil/secure_path.c b/lib/libutil/secure_path.c
index 2847326592b..52ae92b1652 100644
--- a/lib/libutil/secure_path.c
+++ b/lib/libutil/secure_path.c
@@ -1,4 +1,4 @@
-/* $NetBSD: secure_path.c,v 1.1 2001/08/20 14:47:50 wiz Exp $ */
+/* $NetBSD: secure_path.c,v 1.2 2003/01/06 20:30:30 wiz Exp $ */
/*-
* Copyright (c) 1995,1997 Berkeley Software Design, Inc. All rights reserved.
@@ -36,7 +36,7 @@
#include <sys/cdefs.h>
#if defined(LIBC_SCCS) && !defined(lint)
-__RCSID("$NetBSD: secure_path.c,v 1.1 2001/08/20 14:47:50 wiz Exp $");
+__RCSID("$NetBSD: secure_path.c,v 1.2 2003/01/06 20:30:30 wiz Exp $");
#endif /* LIBC_SCCS and not lint */
#include <sys/types.h>
@@ -54,7 +54,7 @@ secure_path(const char *path)
_DIAGASSERT(path != NULL);
/*
* If not a regular file, or is owned/writeable by someone
* other than root, quit.
*/
if (lstat(path, &sb) < 0)
@@ -64,7 +64,7 @@ secure_path(const char *path)
else if (sb.st_uid != 0)
syslog(LOG_ERR, "%s: not owned by root", path);
else if ((sb.st_mode & (S_IWGRP | S_IWOTH)) != 0)
- syslog(LOG_ERR, "%s: writeable by non-root", path);
+ syslog(LOG_ERR, "%s: writable by non-root", path);
else
return (0);
@@ -54,7 +54,7 @@ secure_path(const char *path)
_DIAGASSERT(path != NULL);
/*
- * If not a regular file, or is owned/writeable by someone
+ * If not a regular file, or is owned/writable by someone
* other than root, quit.
*/